==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_external/l10n/eo.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Doni alirpermeson",
    "Error configuring OAuth1" : "Eraro dum agordo de OAuth1",
    "Please provide a valid app key and secret." : "Bv. doni validan aplikaĵan ŝlosilon kaj sekreton.",
    "Error configuring OAuth2" : "Eraro dum agordo de OAuth2",
    "Generate keys" : "Generi ŝlosilojn",
    "Error generating key pair" : "Eraro dum generado de ŝlosila paro",
    "Storage with ID \"%d\" not found" : "Konservejo kun identigilo „%d“ ne trovita",
    "Invalid backend or authentication mechanism class" : "Nevalida interna tipo aŭ aŭtentiga klaso",
    "Invalid mount point" : "Nevalida surmetingo",
    "Objectstore forbidden" : "„Objectstore“ malpermesata",
    "Invalid storage backend \"%s\"" : "Nevalida konserveja interna servo „%s“",
    "Not permitted to use backend \"%s\"" : "Ne permesatas uzi internan servon „%s“",
    "Not permitted to use authentication mechanism \"%s\"" : "Ne permesatas uzi aŭtentigan metodon „%s“",
    "Unsatisfied backend parameters" : "Neplenumitaj internservaj parametroj",
    "Unsatisfied authentication mechanism parameters" : "Neplenumitaj aŭtentigmetodaj parametroj",
    "Insufficient data: %s" : "Nesufiĉaj datumoj: %s",
    "%s" : "%s",
    "Access key" : "Alira ŝlosilo",
    "Secret key" : "Sekreta ŝlosilo",
    "Builtin" : "Interne instalita",
    "None" : "Nenio",
    "OAuth1" : "OAuth1",
    "App key" : "Aplikaĵa ŝlosilo",
    "App secret" : "Aplikaĵosekreto",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klientidentigilo",
    "Client secret" : "Klientosekreto",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Ensaluti",
    "Password" : "Pasvorto",
    "Tenant name" : "Nomo de la loĝanto (angle „tenant“)",
    "Identity endpoint URL" : "Retadreso de identeca finpunkto (angle „Identity endpoint“)",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domajno",
    "Rackspace" : "Rackspace",
    "API key" : "API-ŝlosilo",
    "Global credentials" : "Ĝeneralaj akreditiloj",
    "Log-in credentials, save in database" : "Ensalutaj akreditiloj, konservi en datumbazo",
    "Log-in credentials, save in session" : "Ensalutaj akreditiloj, konservi en seanco",
    "RSA public key" : "Publika RSA-ŝlosilo",
    "Public key" : "Publika ŝlosilo",
    "RSA private key" : "Privata RSA-ŝlosilo",
    "Private key" : "Privata ŝlosilo",
    "Kerberos ticket" : "Kerberos-bileto (angle „ticket“)",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Ujo (angle „bucket“)",
    "Hostname" : "Gastigonomo",
    "Port" : "Pordo",
    "Region" : "Regiono",
    "Enable SSL" : "Ŝalti SSL-on",
    "Enable Path Style" : "Uzi vojan stilon („path style“ angle)",
    "Legacy (v2) authentication" : "Aŭtentigo per malnova v2",
    "WebDAV" : "WebDAV",
    "URL" : "Retadreso",
    "Remote subfolder" : "Fora subdosierujo",
    "Secure https://" : "Sekura https://",
    "FTP" : "FTP",
    "Host" : "Gastigo",
    "Secure ftps://" : "Sekura ftps://",
    "Local" : "Loka",
    "Location" : "Loko",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Radiko",
    "SFTP with secret key login" : "SFTP kun sekretoŝlosila ensaluto",
    "Share" : "Kunhavigi",
    "Show hidden files" : "Montri kaŝitajn dosierojn",
    "Timeout" : "Eltempiĝo",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Servonomo",
    "Request timeout (seconds)" : "Eltempiĝo (sekundoj)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Subteno de cURL en PHP ne estas ebligita aŭ instalita. Surmetado de %s ne eblas. Bv. vidi kun via administranto.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Subteno de FTP en PHP ne estas ebligita aŭ instalita. Surmetado de %s ne eblas. Bv. vidi kun via administranto.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "„%1$s“ ne estas instalita. Surmetado de %2$s ne eblas. Bv. vidi kun via administranto.",
    "External storage" : "Ekstera konservejo",
    "External storage support" : "Subteno de ekstera konservejo",
    "Adds basic external storage support" : "Aldonas bazan subtenon por ekstera konservejo",
    "Confirm" : "Konfirmi",
    "External mount error" : "Eraro de surmetingo ekstera",
    "Storage type" : "Konserveja tipo",
    "Unknown" : "Nekonata",
    "Scope" : "Amplekso",
    "Personal" : "Persona",
    "System" : "Sistemo",
    "(Group)" : "(grupo)",
    "Compatibility with Mac NFD encoding (slow)" : "Kongrueco kun Makintoŝa „NFD“ signara kodoprezento (malrapide)",
    "Enable encryption" : "Ŝalti ĉifradon",
    "Enable previews" : "Ŝalti antaŭrigardojn",
    "Enable sharing" : "Ŝalti kunhavigadon",
    "Check for changes" : "Serĉi la modifojn",
    "Never" : "Neniam",
    "Once every direct access" : "Unufoje okaze de senpera aliro",
    "Read only" : "Nurlega",
    "Disconnect" : "Malkonekti",
    "Admin defined" : "Difinita de administranto",
    "Delete storage?" : "Ĉu forigi konservejon?",
    "Click to recheck the configuration" : "Alklaku por rekontroli la agordon",
    "Saved" : "Konservita",
    "Saving …" : "Konservado...",
    "Save" : "Konservi",
    "No external storage configured or you don't have the permission to configure them" : "Neniu ekstera konservejo agordita, aŭ vi ne rajtas agordi ĝin.",
    "Open documentation" : "Malfermi la dokumentaron",
    "Folder name" : "Dosierujnomo",
    "Authentication" : "Aŭtentigo",
    "Configuration" : "Agordo",
    "Available for" : "Disponebla por",
    "Add storage" : "Aldoni konservejon",
    "Advanced settings" : "Altanivela agordo",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Ĝeneralaj akreditiloj utilas, kiam pluraj eksteraj konservejoj kunuzas la samajn akreditilojn."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_external/l10n/eo.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Doni alirpermeson",
    "Error configuring OAuth2" : "Eraro dum agordo de OAuth2",
    "Generate keys" : "Generi ŝlosilojn",
    "Error generating key pair" : "Eraro dum generado de ŝlosila paro",
    "Storage with ID \"%d\" not found" : "Konservejo kun identigilo „%d“ ne trovita",
    "Invalid backend or authentication mechanism class" : "Nevalida interna tipo aŭ aŭtentiga klaso",
    "Invalid mount point" : "Nevalida surmetingo",
    "Objectstore forbidden" : "„Objectstore“ malpermesata",
    "Invalid storage backend \"%s\"" : "Nevalida konserveja interna servo „%s“",
    "Not permitted to use backend \"%s\"" : "Ne permesatas uzi internan servon „%s“",
    "Not permitted to use authentication mechanism \"%s\"" : "Ne permesatas uzi aŭtentigan metodon „%s“",
    "Unsatisfied backend parameters" : "Neplenumitaj internservaj parametroj",
    "Unsatisfied authentication mechanism parameters" : "Neplenumitaj aŭtentigmetodaj parametroj",
    "Insufficient data: %s" : "Nesufiĉaj datumoj: %s",
    "%s" : "%s",
    "Access key" : "Alira ŝlosilo",
    "Secret key" : "Sekreta ŝlosilo",
    "Builtin" : "Interne instalita",
    "None" : "Nenio",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klientidentigilo",
    "Client secret" : "Klientosekreto",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Ensaluti",
    "Password" : "Pasvorto",
    "Tenant name" : "Nomo de la loĝanto (angle „tenant“)",
    "Identity endpoint URL" : "Retadreso de identeca finpunkto (angle „Identity endpoint“)",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domajno",
    "Rackspace" : "Rackspace",
    "API key" : "API-ŝlosilo",
    "Global credentials" : "Ĝeneralaj akreditiloj",
    "Log-in credentials, save in database" : "Ensalutaj akreditiloj, konservi en datumbazo",
    "Log-in credentials, save in session" : "Ensalutaj akreditiloj, konservi en seanco",
    "RSA public key" : "Publika RSA-ŝlosilo",
    "Public key" : "Publika ŝlosilo",
    "RSA private key" : "Privata RSA-ŝlosilo",
    "Private key" : "Privata ŝlosilo",
    "Kerberos ticket" : "Kerberos-bileto (angle „ticket“)",
    "Bucket" : "Ujo (angle „bucket“)",
    "Hostname" : "Gastigonomo",
    "Port" : "Pordo",
    "Region" : "Regiono",
    "Enable SSL" : "Ŝalti SSL-on",
    "Enable Path Style" : "Uzi vojan stilon („path style“ angle)",
    "Legacy (v2) authentication" : "Aŭtentigo per malnova v2",
    "WebDAV" : "WebDAV",
    "URL" : "Retadreso",
    "Remote subfolder" : "Fora subdosierujo",
    "Secure https://" : "Sekura https://",
    "FTP" : "FTP",
    "Host" : "Gastigo",
    "Secure ftps://" : "Sekura ftps://",
    "Local" : "Loka",
    "Location" : "Loko",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Radiko",
    "SFTP with secret key login" : "SFTP kun sekretoŝlosila ensaluto",
    "Share" : "Kunhavigi",
    "Show hidden files" : "Montri kaŝitajn dosierojn",
    "Timeout" : "Eltempiĝo",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Servonomo",
    "Request timeout (seconds)" : "Eltempiĝo (sekundoj)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Subteno de cURL en PHP ne estas ebligita aŭ instalita. Surmetado de %s ne eblas. Bv. vidi kun via administranto.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Subteno de FTP en PHP ne estas ebligita aŭ instalita. Surmetado de %s ne eblas. Bv. vidi kun via administranto.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "„%1$s“ ne estas instalita. Surmetado de %2$s ne eblas. Bv. vidi kun via administranto.",
    "External storage" : "Ekstera konservejo",
    "External storage support" : "Subteno de ekstera konservejo",
    "Adds basic external storage support" : "Aldonas bazan subtenon por ekstera konservejo",
    "Confirm" : "Konfirmi",
    "External mount error" : "Eraro de surmetingo ekstera",
    "Storage type" : "Konserveja tipo",
    "Unknown" : "Nekonata",
    "Scope" : "Amplekso",
    "Personal" : "Persona",
    "System" : "Sistemo",
    "(Group)" : "(grupo)",
    "Compatibility with Mac NFD encoding (slow)" : "Kongrueco kun Makintoŝa „NFD“ signara kodoprezento (malrapide)",
    "Enable encryption" : "Ŝalti ĉifradon",
    "Enable previews" : "Ŝalti antaŭrigardojn",
    "Enable sharing" : "Ŝalti kunhavigadon",
    "Check for changes" : "Serĉi la modifojn",
    "Never" : "Neniam",
    "Once every direct access" : "Unufoje okaze de senpera aliro",
    "Read only" : "Nurlega",
    "Disconnect" : "Malkonekti",
    "Admin defined" : "Difinita de administranto",
    "Delete storage?" : "Ĉu forigi konservejon?",
    "Click to recheck the configuration" : "Alklaku por rekontroli la agordon",
    "Saved" : "Konservita",
    "Save" : "Konservi",
    "No external storage configured or you don't have the permission to configure them" : "Neniu ekstera konservejo agordita, aŭ vi ne rajtas agordi ĝin.",
    "Open documentation" : "Malfermi la dokumentaron",
    "Folder name" : "Dosierujnomo",
    "Authentication" : "Aŭtentigo",
    "Configuration" : "Agordo",
    "Available for" : "Disponebla por",
    "Add storage" : "Aldoni konservejon",
    "Advanced settings" : "Altanivela agordo",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Ĝeneralaj akreditiloj utilas, kiam pluraj eksteraj konservejoj kunuzas la samajn akreditilojn.",
    "Error configuring OAuth1" : "Eraro dum agordo de OAuth1",
    "Please provide a valid app key and secret." : "Bv. doni validan aplikaĵan ŝlosilon kaj sekreton.",
    "OAuth1" : "OAuth1",
    "App key" : "Aplikaĵa ŝlosilo",
    "App secret" : "Aplikaĵosekreto",
    "Saving …" : "Konservado..."
},
"nplurals=2; plural=(n != 1);");
